@@ -330,6 +330,28 @@ class ConfiguredActionList(ActionList):
             return ConfiguredAction(action)
 
 
+class ConfigurableInstance:
+    methods_to_register: List[str] = []
+
+    def __init__(self):
+        """
+        A base class which will register a class instance's methods as ConfiguredActions. The method names in the
+        methods_to_register list will be registered as configured actions upon instantiation.
+
+        Subclasses should overwrite the list of methods to register and call init.
+        """
+        self._register_instance_actions()
+
+    def _register_instance_actions(self):
+        """registers instance actions as ConfiguredActions"""
+        for method_name in self.methods_to_register:
+            setattr(
+                self,
+                method_name,
+                ConfiguredAction(getattr(self, method_name))
+            )
+
+
 def ensure_triggered(fn: Callable):
     """decorator which will do the thing you want"""
     @wraps(fn)
